==> mit-scheme-c-9.0.1.tar.gz: mit-scheme-c-9.0.1/src/imail/ed-ffi.scm <==
#| -*-Scheme-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010 Massachusetts Institute of Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

|#

;;;; IMAIL mail reader: Edwin buffer packaging info

(standard-scheme-find-file-initialization
 '#(("imail-browser"	(edwin imail front-end folder-browser))
    ("imail-core"	(edwin imail))
    ("imail-file"	(edwin imail file-folder))
    ("imail-imap"	(edwin imail imap-folder))
    ("imail-mime"	(edwin imail))
    ("imail-rmail"	(edwin imail file-folder rmail-folder))
    ("imail-summary"	(edwin imail front-end summary))
    ("imail-top"	(edwin imail front-end))
    ("imail-umail"	(edwin imail file-folder umail-folder))
    ("imail-util"	(edwin imail))
    ("imap-response"	(edwin imail imap-response))
    ("imap-syntax"	(edwin imail imap-syntax))))

==> mit-scheme-c-9.2.tar.gz: mit-scheme-c-9.2/src/imail/ed-ffi.scm <==
#| -*-Scheme-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Massachusetts
    Institute of Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

|#

;;;; IMAIL mail reader: Edwin buffer packaging info

(standard-scheme-find-file-initialization
 '#(("imail-browser"	(edwin imail front-end folder-browser))
    ("imail-core"	(edwin imail))
    ("imail-file"	(edwin imail file-folder))
    ("imail-imap"	(edwin imail imap-folder))
    ("imail-mime"	(edwin imail))
    ("imail-rmail"	(edwin imail file-folder rmail-folder))
    ("imail-summary"	(edwin imail front-end summary))
    ("imail-top"	(edwin imail front-end))
    ("imail-umail"	(edwin imail file-folder umail-folder))
    ("imail-util"	(edwin imail))
    ("imap-response"	(edwin imail imap-response))
    ("imap-syntax"	(edwin imail imap-syntax))))
